"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateSearchVocabularies = void 0;
const SearchVocabulariesCommand_1 = require("../commands/SearchVocabulariesCommand");
const Connect_1 = require("../Connect");
const ConnectClient_1 = require("../ConnectClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new SearchVocabulariesCommand_1.SearchVocabulariesCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.searchVocabularies(input, ...args);
};
async function* paginateSearchVocabularies(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof Connect_1.Connect) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof ConnectClient_1.ConnectClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected Connect | ConnectClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateSearchVocabularies = paginateSearchVocabularies;
