import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { CreateQuickConnectRequest, CreateQuickConnectResponse } from "../models/models_0";
export interface CreateQuickConnectCommandInput extends CreateQuickConnectRequest {
}
export interface CreateQuickConnectCommandOutput extends CreateQuickConnectResponse, __MetadataBearer {
}
/**
 * <p>Creates a quick connect for the specified Amazon Connect instance.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, CreateQuickConnectCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, CreateQuickConnectCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const command = new CreateQuickConnectCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link CreateQuickConnectCommandInput} for command's `input` shape.
 * @see {@link CreateQuickConnectCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 */
export declare class CreateQuickConnectCommand extends $Command<CreateQuickConnectCommandInput, CreateQuickConnectCommandOutput, ConnectClientResolvedConfig> {
    readonly input: CreateQuickConnectCommandInput;
    constructor(input: CreateQuickConnectCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectClientResolvedConfig, options?: __HttpHandlerOptions): Handler<CreateQuickConnectCommandInput, CreateQuickConnectCommandOutput>;
    private serialize;
    private deserialize;
}
