import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { SearchVocabulariesRequest, SearchVocabulariesResponse } from "../models/models_0";
export interface SearchVocabulariesCommandInput extends SearchVocabulariesRequest {
}
export interface SearchVocabulariesCommandOutput extends SearchVocabulariesResponse, __MetadataBearer {
}
/**
 * <p>Searches for vocabularies within a specific Amazon Connect instance using <code>State</code>, <code>NameStartsWith</code>, and <code>LanguageCode</code>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, SearchVocabulariesCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, SearchVocabulariesCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const command = new SearchVocabulariesCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link SearchVocabulariesCommandInput} for command's `input` shape.
 * @see {@link SearchVocabulariesCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 */
export declare class SearchVocabulariesCommand extends $Command<SearchVocabulariesCommandInput, SearchVocabulariesCommandOutput, ConnectClientResolvedConfig> {
    readonly input: SearchVocabulariesCommandInput;
    constructor(input: SearchVocabulariesCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectClientResolvedConfig, options?: __HttpHandlerOptions): Handler<SearchVocabulariesCommandInput, SearchVocabulariesCommandOutput>;
    private serialize;
    private deserialize;
}
