import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { StartOutboundVoiceContactRequest, StartOutboundVoiceContactResponse } from "../models/models_1";
export interface StartOutboundVoiceContactCommandInput extends StartOutboundVoiceContactRequest {
}
export interface StartOutboundVoiceContactCommandOutput extends StartOutboundVoiceContactResponse, __MetadataBearer {
}
/**
 * <p>Places an outbound call to a contact, and then initiates the contact flow. It performs the
 *    actions in the contact flow that's specified (in <code>ContactFlowId</code>).</p>
 *
 *          <p>Agents do not initiate the outbound API, which means that they do not dial the contact. If
 *    the contact flow places an outbound call to a contact, and then puts the contact in queue, the
 *    call is then routed to the agent, like any other inbound case.</p>
 *
 *          <p>There is a 60-second dialing timeout for this operation. If the call is not connected after
 *    60 seconds, it fails.</p>
 *          <note>
 *             <p>UK numbers with a 447 prefix are not allowed by default. Before you can dial these UK
 *     mobile numbers, you must submit a service quota increase request. For more information, see
 *      <a href="https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html">Amazon Connect Service Quotas</a> in the <i>Amazon Connect Administrator Guide</i>. </p>
 *          </note>
 *          <note>
 *             <p>Campaign calls are not allowed by default. Before you can make a call with
 *      <code>TrafficType</code> = <code>CAMPAIGN</code>, you must submit a service quota increase
 *     request. For more information, see <a href="https://docs.aws.amazon.com/connect/latest/adminguide/amazon-connect-service-limits.html">Amazon Connect Service Quotas</a>
 *     in the <i>Amazon Connect Administrator Guide</i>. </p>
 *          </note>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, StartOutboundVoiceContactCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, StartOutboundVoiceContactCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const command = new StartOutboundVoiceContactCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link StartOutboundVoiceContactCommandInput} for command's `input` shape.
 * @see {@link StartOutboundVoiceContactCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 */
export declare class StartOutboundVoiceContactCommand extends $Command<StartOutboundVoiceContactCommandInput, StartOutboundVoiceContactCommandOutput, ConnectClientResolvedConfig> {
    readonly input: StartOutboundVoiceContactCommandInput;
    constructor(input: StartOutboundVoiceContactCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectClientResolvedConfig, options?: __HttpHandlerOptions): Handler<StartOutboundVoiceContactCommandInput, StartOutboundVoiceContactCommandOutput>;
    private serialize;
    private deserialize;
}
