import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ConnectClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ConnectClient";
import { UpdateQuickConnectConfigRequest } from "../models/models_1";
export interface UpdateQuickConnectConfigCommandInput extends UpdateQuickConnectConfigRequest {
}
export interface UpdateQuickConnectConfigCommandOutput extends __MetadataBearer {
}
/**
 * <p>Updates the configuration settings for the specified quick connect.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ConnectClient, UpdateQuickConnectConfigCommand } from "@aws-sdk/client-connect"; // ES Modules import
 * // const { ConnectClient, UpdateQuickConnectConfigCommand } = require("@aws-sdk/client-connect"); // CommonJS import
 * const client = new ConnectClient(config);
 * const command = new UpdateQuickConnectConfigCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link UpdateQuickConnectConfigCommandInput} for command's `input` shape.
 * @see {@link UpdateQuickConnectConfigCommandOutput} for command's `response` shape.
 * @see {@link ConnectClientResolvedConfig | config} for ConnectClient's `config` shape.
 *
 */
export declare class UpdateQuickConnectConfigCommand extends $Command<UpdateQuickConnectConfigCommandInput, UpdateQuickConnectConfigCommandOutput, ConnectClientResolvedConfig> {
    readonly input: UpdateQuickConnectConfigCommandInput;
    constructor(input: UpdateQuickConnectConfigCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: ConnectClientResolvedConfig, options?: __HttpHandlerOptions): Handler<UpdateQuickConnectConfigCommandInput, UpdateQuickConnectConfigCommandOutput>;
    private serialize;
    private deserialize;
}
